==> ecamegapedal_0.2.0.orig.tar.gz: ecamegapedal-0.2.0/src/ecamegapedal.cpp <==
// ------------------------------------------------------------------------
// ecamegapedal.cpp: A graphical realtime effect processing app.
// Copyright (C) 2001 Kai Vehmanen (kaiv@wakkanet.fi)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
// ------------------------------------------------------------------------

#include <iostream>

#include <qapplication.h>
#include <qpushbutton.h>
#include <signal.h>

#include <kvutils/definition_by_contract.h>
#include <kvutils/com_line.h>
#include <ecasound/eca-error.h>
#include <ecasound/eca-debug.h>
#include <ecasound/eca-version.h>

#include "version.h"

#include "interface.h"
#include "ecamegapedal.h"

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif
#ifdef USE_CXX_STD_NAMESPACE
using namespace std;
#endif

int main(int argc, char **argv) {
//    ecadebug->set_debug_level(ECA_DEBUG::info |
//  			    ECA_DEBUG::module_flow);

  try {
    COMMAND_LINE cline = COMMAND_LINE (argc, argv);
    parse_command_line(cline);

    QApplication qapp (argc, argv);
    string input ("/dev/dsp");
    string output ("/dev/dsp");
    if (argc > 1) input = string(argv[1]);
    if (argc > 2) output = string(argv[2]);
    QEInterface ewinterface (input, output);
    qapp.setMainWidget(&ewinterface);
    ewinterface.show();
    
    QObject::connect( &qapp, SIGNAL( lastWindowClosed() ), &qapp, SLOT( quit() ) );
    return(qapp.exec());
  }
  catch(DBC_EXCEPTION& e) { 
    cerr << "Failed condition \"" 
	 << e.type_repp 
         << ":" 
         << e.expression_repp
	 << "\": file " 
	 << e.file_repp 
	 << ", line " 
	 << e.line_rep 
	 << "." 
	 << endl;
    exit(1);
  }
  catch(ECA_ERROR& e) { 
    cerr << "---\nlibecasound error while processing event: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
  }
  catch(...) {
    cerr << "---\nCaught an unknown exception!\n";
  }
}

void parse_command_line(COMMAND_LINE& cline) {
  cline.begin();
  while(cline.end() == false) {
    if (cline.current() == "--version") {
      cout << "ecamegapedal v" << ecamegapedal_version
	   << " - [libecasound "
	   << ecasound_library_version
	   << "]" << endl;
      cout << "Copyright (C) 2001 Kai Vehmanen" << endl;
      cout << "Ecamegapedal comes with ABSOLUTELY NO WARRANTY." << endl;
      cout << "You may redistribute copies of ecamegapedal under the terms of the GNU" << endl;
      cout << "General Public License. For more information about these matters, see" << endl; 
      cout << "the file named COPYING." << endl;
      exit(0);
    }
    else if (cline.current() == "--help") {
	cout << "USAGE: ecamegapedal [options] [<input> <output>]\n"
	     << "    --version   print version info" << endl
	     << "    --help      show this help" << endl << endl;
	cout << "For a more detailed documentation, see ecamegapedal(1) man page." << endl;
	cout << "Report bugs to <k@eca.cx>." << endl;
	exit(0);
    }
    cline.next();
  }
}

==> ecamegapedal-0.4.2.tar.gz: ecamegapedal-0.4.2/src/ecamegapedal.cpp <==
// ------------------------------------------------------------------------
// ecamegapedal.cpp: A graphical realtime effect processing app.
// Copyright (C) 2001-2003 Kai Vehmanen (kai.vehmanen@wakkanet.fi)
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
// ------------------------------------------------------------------------

#include <iostream>
#include <signal.h> /* sigaction() */

#include <qapplication.h>
#include <qpushbutton.h>

#include <kvu_com_line.h>
#include <eca-error.h>
#include <eca-logger.h>
#include <eca-version.h>

#include "version.h"

#include "interface.h"
#include "ecamegapedal.h"

using std::string;
using std::cerr;
using std::cout;
using std::endl;

static void ecamegapedal_setup_signals(void);

int main(int argc, char **argv) {

  ecamegapedal_setup_signals();

  ECA_LOGGER::instance().disable();
  // ECA_LOGGER::instance().set_log_level(ECA_LOGGER::errors, true);
  // ECA_LOGGER::instance().set_log_level(ECA_LOGGER::info, true);
  // ECA_LOGGER::instance().set_log_level(ECA_LOGGER::subsystems, true);

  try {
    COMMAND_LINE cline = COMMAND_LINE (argc, argv);
    parse_command_line(cline);

    QApplication qapp (argc, argv);

    QEInterface ewinterface;

    /* set the default input and output */
    if (argc > 1) ewinterface.set_input_name(argv[1]);
    if (argc > 2) ewinterface.set_output_name(argv[2]);

    /* start the user interface */
    qapp.setMainWidget(&ewinterface);
    ewinterface.show();
    
    QObject::connect( &qapp, SIGNAL( lastWindowClosed() ), &qapp, SLOT( quit() ) );

    return(qapp.exec());
  }
  catch(ECA_ERROR& e) { 
    cerr << "---\nlibecasound error while processing event: [" << e.error_section() << "] : \"" << e.error_message() << "\"\n\n";
  }
  catch(...) {
    cerr << "---\nCaught an unknown exception!\n";
  }
}

void parse_command_line(COMMAND_LINE& cline) {
  cline.begin();
  while(cline.end() == false) {
    if (cline.current() == "--version") {
      cout << "ecamegapedal v" << ecamegapedal_version
	   << " - [libecasound "
	   << ecasound_library_version
	   << "]" << endl;
      cout << "Copyright (C) 2001-2003 Kai Vehmanen" << endl;
      cout << "Ecamegapedal comes with ABSOLUTELY NO WARRANTY." << endl;
      cout << "You may redistribute copies of ecamegapedal under the terms of the GNU" << endl;
      cout << "General Public License. For more information about these matters, see" << endl; 
      cout << "the file named COPYING." << endl;
      exit(0);
    }
    else if (cline.current() == "--help") {
	cout << "USAGE: ecamegapedal [options] [<input> <output>]\n"
	     << "    --version   print version info" << endl
	     << "    --help      show this help" << endl << endl;
	cout << "For a more detailed documentation, see ecamegapedal(1) man page." << endl;
	cout << "Report bugs to <k@eca.cx>." << endl;
	exit(0);
    }
    cline.next();
  }
}

void ecamegapedal_setup_signals(void)
{
  struct sigaction ign_handler;
  ign_handler.sa_handler = SIG_IGN;
  sigemptyset(&ign_handler.sa_mask);
  ign_handler.sa_flags = 0;

  /* handle the follwing signals explicitly */
  /* -none- */

  /* ignore the following signals */
  sigaction(SIGPIPE, &ign_handler, 0);
}
